==> tesseract_2.04.orig.tar.gz: tesseract-2.04/cutil/globals.cpp <==
/*
################################################################################
#
# File:         globals.c
# Description:  Global flag definitions
# Author:       Mark Seaman, OCR Technology
# Created:      Thu Oct 19 16:51:26 1989
# Modified:     Fri Jan 26 13:16:37 1990 (Mark Seaman) marks@hpgrlt
# Language:     Text
# Package:      N/A
# Status:       Experimental (Do Not Distribute)
#
# (c) Copyright 1989, Hewlett-Packard Company.
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
** http://www.apache.org/licenses/LICENSE-2.0
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
#
################################################################################
**************************************************************************/
#include <stdio.h>
#include "globals.h"

/* This file contains the global declarations used by all demonstrator files*/

//IMAGE                                         info;                                           /*image info record*/
TBLOB *pageblobs;                /*first blob on page */
TEXTBLOCK *pageblocks;           /*first block on page */
// char classes[CLASSIZE][CLASSLENGTH];
                                 /*class definitions */
                                 /*indices to to_classes */

int resolution;                  /*scanner res in dpi */
int acts[MAXPROC];               /*action flags */
int debugs[MAXPROC];             /*debug flags */
int plots[MAXPROC];              /*plot flags */

/*----------------------------------------------------------------------
              V a r i a b l e s
----------------------------------------------------------------------*/
int corners[4];                  /*corners of scan window */

char imagefile[FILENAMESIZE];    /*image file name */
char directory[FILENAMESIZE];    /* main directory */
char *debugfile;                 /* debug file name */

int plots_fx;
int plots_ocr;

int debugs_fx;
int debugs_ocr;

int acts_fx;
int acts_ocr;

char *demodir;                   /*demo home directory */

int edgefd;                      /*edges window */
int debugfd;                     /*debug window fd */
FILE *debugfp;                   /*debug log file */

UNICHARSET unicharset;

STRING language_data_path_prefix;

==> tesseract-3.00.tar.gz: tesseract-3.00/cutil/globals.cpp <==
/*
################################################################################
#
# File:         globals.c
# Description:  Global flag definitions
# Author:       Mark Seaman, OCR Technology
# Created:      Thu Oct 19 16:51:26 1989
# Modified:     Fri Jan 26 13:16:37 1990 (Mark Seaman) marks@hpgrlt
# Language:     Text
# Package:      N/A
# Status:       Experimental (Do Not Distribute)
#
# (c) Copyright 1989, Hewlett-Packard Company.
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
** http://www.apache.org/licenses/LICENSE-2.0
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
#
################################################################################
**************************************************************************/
#include <stdio.h>
#include "globals.h"

/* This file contains the global declarations used by all demonstrator files*/

//IMAGE                                         info;                                           /*image info record*/
//TBLOB *pageblobs;                /*first blob on page */
//TEXTBLOCK *pageblocks;           /*first block on page */
// char classes[CLASSIZE][CLASSLENGTH];
                                 /*class definitions */
                                 /*indices to to_classes */

//int resolution;                  /*scanner res in dpi */
//int acts[MAXPROC];               /*action flags */
//int debugs[MAXPROC];             /*debug flags */
//int plots[MAXPROC];              /*plot flags */

/*----------------------------------------------------------------------
              V a r i a b l e s
----------------------------------------------------------------------*/
//int corners[4];                  /*corners of scan window */

//char imagefile[FILENAMESIZE];    /*image file name */
//char directory[FILENAMESIZE];    /* main directory */
//char *debugfile;                 /* debug file name */

//int plots_fx;
//int plots_ocr;

//int debugs_fx;
//int debugs_ocr;

//int acts_fx;
//int acts_ocr;

//char *demodir;                   /*demo home directory */

//int edgefd;                      /*edges window */
//int debugfd;                     /*debug window fd */
//FILE *debugfp;                   /*debug log file */

//UNICHARSET unicharset;

//STRING language_data_path_prefix;
